@@ -589,6 +589,20 @@ add_dingus (VteTerminal *terminal,
         }
 }
 
+static void
+spawn_cb (VteTerminal *terminal,
+          GPid pid,
+          GError *error,
+          gpointer user_data)
+{
+        if (pid == -1) {
+                g_printerr("Spawning failed: %s\n", error->message);
+                return;
+        }
+
+        g_printerr("Spawning succeded, PID %ld\n", (long)pid);
+}
+
 int
 main(int argc, char **argv)
 {
@@ -1109,7 +1123,6 @@ main(int argc, char **argv)
 			GError *err = NULL;
 			char **command_argv = NULL;
 			int command_argc;
-			GPid pid = -1;
                         char *free_me = NULL;
 
 			_VTE_DEBUG_IF(VTE_DEBUG_MISC)
@@ -1124,23 +1137,21 @@ main(int argc, char **argv)
 			if (command == NULL || *command == '\0')
 				command = "/bin/sh";
 
-			if (!g_shell_parse_argv(command, &command_argc, &command_argv, &err) ||
-			    !vte_terminal_spawn_sync(terminal,
-							    pty_flags,
-							    NULL,
-							    command_argv,
-							    env_add,
-							    G_SPAWN_SEARCH_PATH,
-							    NULL, NULL,
-							    &pid,
-                                                            NULL /* cancellable */,
-							    &err)) {
-				g_warning("Failed to fork: %s\n", err->message);
+			if (!g_shell_parse_argv(command, &command_argc, &command_argv, &err)) {
+				g_warning("Failed to parse argv: %s\n", err->message);
 				g_error_free(err);
-			} else {
-				g_print("Fork succeeded, PID %d\n", pid);
-			}
+                        }
 
+                        vte_terminal_spawn_async(terminal,
+                                                 pty_flags,
+                                                 working_directory,
+                                                 command_argv,
+                                                 env_add,
+                                                 G_SPAWN_SEARCH_PATH_FROM_ENVP,
+                                                 NULL, NULL, NULL,
+                                                 30 * 1000 /* 30s */,
+                                                 NULL /* cancellable */,
+                                                 spawn_cb, NULL);
                         g_free (free_me);
 			g_strfreev(command_argv);
 		} else {
